@@ -38,6 +38,14 @@
 #include "filecheck.h"
 #include "auth.h"
 
+/* Ensure we know about FamilyInternetV6 even if what we're compiling
+   against doesn't */
+#ifdef ENABLE_IPV6
+#ifndef FamilyInternetV6
+#define FamilyInternetV6	6
+#endif /* ! FamilyInternetV6 */
+#endif /* ENABLE_IPV6 */
+
 /* Local prototypes */
 static FILE *gdm_auth_purge (GdmDisplay *d, FILE *af, gboolean remove_when_empty);
 
@@ -63,8 +71,8 @@ display_add_error (GdmDisplay *d)
 			   "add_auth_entry");
 	if (d->console) {
 		char *s = g_strdup_printf
-			(_("GDM could not write a new authorization "
-			   "entry to disk.  Possibly out of diskspace.%s%s"),
+			(C_(N_("GDM could not write a new authorization "
+			       "entry to disk.  Possibly out of diskspace.%s%s")),
 			 errno != 0 ? "  Error: " : "",
 			 errno != 0 ? strerror (errno) : "");
 		gdm_text_message_dialog (s);
@@ -403,7 +411,7 @@ get_local_auths (GdmDisplay *d)
 	    /* we should write out an entry for d->addr since
 	       possibly it is not in d->addrs */
 #ifdef ENABLE_IPV6
-	    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternet, (char *)((d->addr6).s6_addr), sizeof (struct in6_addr)))
+	    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternetV6, (char *)((d->addr6).s6_addr), sizeof (struct in6_addr)))
 		    goto get_local_auth_error;
 	    else
 #endif
@@ -432,7 +440,7 @@ get_local_auths (GdmDisplay *d)
 		    if (memcmp (ia6, &(d->addr6), sizeof (struct in6_addr)) == 0)
 			    continue;
 
-		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternet, (char *)(ia6->s6_addr), sizeof (struct in6_addr)))
+		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternetV6, (char *)(ia6->s6_addr), sizeof (struct in6_addr)))
 			    goto get_local_auth_error;
 
 		    if (gdm_is_loopback_addr6 (ia6))
@@ -463,7 +471,7 @@ get_local_auths (GdmDisplay *d)
 
 #ifdef ENABLE_IPV6
 	    if (ia->sa_family == AF_INET6) {
-		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternet, (char *)(((struct sockaddr_in6 *)ia)->sin6_addr.s6_addr), sizeof (struct in6_addr)))
+		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternetV6, (char *)(((struct sockaddr_in6 *)ia)->sin6_addr.s6_addr), sizeof (struct in6_addr)))
 			    goto get_local_auth_error;
 
 		    if (gdm_is_loopback_addr6 (&((struct sockaddr_in6 *)ia)->sin6_addr))
@@ -486,7 +494,7 @@ get_local_auths (GdmDisplay *d)
 
 #ifdef ENABLE_IPV6
 	    if (d->addrtype == AF_INET6) {
-		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternet, lo6, sizeof (struct in6_addr)))
+		    if ( ! add_auth_entry (d, &auths, NULL, NULL, FamilyInternetV6, lo6, sizeof (struct in6_addr)))
 			    goto get_local_auth_error;
 	    }
 	    else
