@@ -71,6 +71,8 @@ struct _GdmConnection {
 
 	GList *subconnections;
 	int n_subconnections;
+
+	GdmDisplay *disp;
 };
 
 static gboolean
@@ -103,7 +105,7 @@ gdm_connection_handler (GIOChannel *source,
 	if ( ! (cond & G_IO_IN)) 
 		return close_if_needed (conn, cond);
 
-	IGNORE_EINTR (len = read (conn->fd, buf, sizeof (buf) -1));
+	VE_IGNORE_EINTR (len = read (conn->fd, buf, sizeof (buf) -1));
 	if (len <= 0) {
 		return close_if_needed (conn, cond);
 	}
@@ -172,11 +174,11 @@ gdm_connection_write (GdmConnection *conn, const char *str)
 #endif
 
 #ifdef MSG_NOSIGNAL
-	IGNORE_EINTR (ret = send (conn->fd, str, strlen (str), MSG_NOSIGNAL | flags));
+	VE_IGNORE_EINTR (ret = send (conn->fd, str, strlen (str), MSG_NOSIGNAL | flags));
 	save_errno = errno;
 #else
 	old_handler = signal (SIGPIPE, SIG_IGN);
-	IGNORE_EINTR (ret = send (conn->fd, str, strlen (str), flags));
+	VE_IGNORE_EINTR (ret = send (conn->fd, str, strlen (str), flags));
 	save_errno = errno;
 	signal (SIGPIPE, old_handler);
 #endif
@@ -205,7 +207,7 @@ gdm_socket_handler (GIOChannel *source,
 	if ( ! (cond & G_IO_IN)) 
 		return TRUE;
 
-	IGNORE_EINTR (fd = accept (conn->fd,
+	VE_IGNORE_EINTR (fd = accept (conn->fd,
 				   (struct sockaddr *)&addr,
 				   &addr_size));
 	if G_UNLIKELY (fd < 0) {
@@ -216,6 +218,7 @@ gdm_socket_handler (GIOChannel *source,
 	gdm_debug ("gdm_socket_handler: Accepting new connection fd %d", fd);
 
 	newconn = g_new0 (GdmConnection, 1);
+	newconn->disp = NULL;
 	newconn->message_count = 0;
 	newconn->nonblock = conn->nonblock;
 	newconn->close_level = 0;
@@ -272,7 +275,7 @@ gdm_connection_open_unix (const char *sockname, mode_t mode)
 
 try_again:
 	/* this is all for creating sockets in /tmp/ safely */
-	IGNORE_EINTR (unlink (sockname));
+	VE_IGNORE_EINTR (unlink (sockname));
 	if G_UNLIKELY (errno == EISDIR ||
 		       errno == EPERM) {
 		/* likely a directory, someone's playing tricks on us */
@@ -283,7 +286,7 @@ try_again:
 						   sockname,
 						   (guint)g_random_int ());
 		} while (access (newname, F_OK) == 0);
-		IGNORE_EINTR (rename (sockname, newname));
+		VE_IGNORE_EINTR (rename (sockname, newname));
 		if G_UNLIKELY (errno != 0)
 			try_again_attempts = 0;
 		g_free (newname);
@@ -302,13 +305,14 @@ try_again:
 		/* someone is being evil on us */
 		if (errno == EADDRINUSE && try_again_attempts >= 0)
 			goto try_again;
-		IGNORE_EINTR (close (fd));
+		VE_IGNORE_EINTR (close (fd));
 		return NULL;
 	}
 
-	IGNORE_EINTR (chmod (sockname, mode));
+	VE_IGNORE_EINTR (chmod (sockname, mode));
 
 	conn = g_new0 (GdmConnection, 1);
+	conn->disp = NULL;
 	conn->message_count = 0;
 	conn->nonblock = FALSE;
 	conn->close_level = 0;
@@ -345,6 +349,7 @@ gdm_connection_open_fd (int fd)
 	g_return_val_if_fail (fd >= 0, NULL);
 
 	conn = g_new0 (GdmConnection, 1);
+	conn->disp = NULL;
 	conn->message_count = 0;
 	conn->nonblock = FALSE;
 	conn->close_level = 0;
@@ -377,7 +382,7 @@ gdm_connection_open_fifo (const char *fifo, mode_t mode)
 	GdmConnection *conn;
 	int fd;
 
-	IGNORE_EINTR (unlink (fifo));
+	VE_IGNORE_EINTR (unlink (fifo));
 
 	if G_UNLIKELY (mkfifo (fifo, 0660) < 0) {
 		gdm_error (_("%s: Could not make FIFO"),
@@ -393,9 +398,10 @@ gdm_connection_open_fifo (const char *fifo, mode_t mode)
 		return NULL;
 	}
 
-	IGNORE_EINTR (chmod (fifo, mode));
+	VE_IGNORE_EINTR (chmod (fifo, mode));
 
 	conn = g_new0 (GdmConnection, 1);
+	conn->disp = NULL;
 	conn->message_count = 0;
 	conn->nonblock = FALSE;
 	conn->close_level = 0;
@@ -504,7 +510,7 @@ gdm_connection_close (GdmConnection *conn)
 	}
 
 	if (conn->fd > 0) {
-		IGNORE_EINTR (close (conn->fd));
+		VE_IGNORE_EINTR (close (conn->fd));
 		conn->fd = -1;
 	}
 
@@ -568,4 +574,43 @@ gdm_connection_set_nonblock (GdmConnection *conn,
 	conn->nonblock = nonblock;
 }
 
+GdmDisplay *
+gdm_connection_get_display (GdmConnection *conn)
+{
+	g_return_val_if_fail (conn != NULL, NULL);
+	return conn->disp;
+}
+
+void
+gdm_connection_set_display (GdmConnection *conn,
+			    GdmDisplay *disp)
+{
+	g_return_if_fail (conn != NULL);
+	conn->disp = disp;
+}
+
+void
+gdm_kill_subconnections_with_display (GdmConnection *conn,
+				      GdmDisplay *disp)
+{
+	GList *subs;
+
+	g_return_if_fail (conn != NULL);
+	g_return_if_fail (disp != NULL);
+
+	subs = conn->subconnections;
+	while (subs != NULL) {
+		GdmConnection *subcon = subs->data;
+		if (subcon->disp == disp) {
+			subcon->disp = NULL;
+			conn->subconnections =
+				g_list_remove (conn->subconnections, subcon);
+			gdm_connection_close (subcon);
+			subs = conn->subconnections;
+		} else {
+			subs = subs->next;
+		}
+	}
+}
+
 /* EOF */
