@@ -57,6 +57,7 @@ extern gboolean GdmDebug;
 extern GSList *displays;
 extern int gdm_xdmcpfd;
 extern gboolean GdmXdmcp;
+extern gchar *GdmConsoleCannotHandle;
 
 extern char **environ;
 
@@ -492,13 +493,27 @@ gdm_text_message_dialog (const char *msg)
 	if (access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) != 0)
 		return FALSE;
 
-	msg_quoted = g_shell_quote (msg);
+	if (msg[0] == '-') {
+		char *tmp = g_strconcat (" ", msg, NULL);
+		msg_quoted = g_shell_quote (tmp);
+		g_free (tmp);
+	} else {
+		msg_quoted = g_shell_quote (msg);
+	}
 	
 	dialog = g_find_program_in_path ("dialog");
 	if (dialog == NULL)
 		dialog = g_find_program_in_path ("whiptail");
 	if (dialog != NULL) {
 		char *argv[6];
+
+		if ( ! gdm_ok_console_language ()) {
+			ve_unsetenv ("LANG");
+			ve_unsetenv ("LC_ALL");
+			ve_unsetenv ("LC_MESSAGES");
+			ve_setenv ("LANG", "C", TRUE);
+			ve_setenv ("UNSAFE_TO_TRANSLATE", "yes", TRUE);
+		}
 		
 		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
@@ -559,7 +574,13 @@ gdm_text_yesno_dialog (const char *msg, gboolean *ret)
 	if (ret != NULL)
 		*ret = FALSE;
 
-	msg_quoted = g_shell_quote (msg);
+	if (msg[0] == '-') {
+		char *tmp = g_strconcat (" ", msg, NULL);
+		msg_quoted = g_shell_quote (tmp);
+		g_free (tmp);
+	} else {
+		msg_quoted = g_shell_quote (msg);
+	}
 	
 	dialog = g_find_program_in_path ("dialog");
 	if (dialog == NULL)
@@ -568,6 +589,14 @@ gdm_text_yesno_dialog (const char *msg, gboolean *ret)
 		char *argv[6];
 		int retint;
 
+		if ( ! gdm_ok_console_language ()) {
+			ve_unsetenv ("LANG");
+			ve_unsetenv ("LC_ALL");
+			ve_unsetenv ("LC_MESSAGES");
+			ve_setenv ("LANG", "C", TRUE);
+			ve_setenv ("UNSAFE_TO_TRANSLATE", "yes", TRUE);
+		}
+
 		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
 		argv[2] = "/bin/sh";
@@ -842,13 +871,45 @@ gdm_wait_for_extra (int *status)
 	gdm_sigchld_block_pop ();
 }
 
-/* done before each login and on startup.  This can do some
- * sanity ensuring, one of the things it does now is make
- * sure /tmp/.ICE-unix exists and has the correct permissions */
+static void
+ensure_tmp_socket_dir (const char *dir)
+{
+	mode_t old_umask;
+
+	/* The /tmp/.ICE-unix / .X11-unix check, note that we do
+	 * ignore errors, since it's not deadly to run
+	 * if we can't perform this task :) */
+	old_umask = umask (0);
+
+        if G_UNLIKELY (mkdir (dir, 01777) != 0) {
+		/* if we can't create it, perhaps it
+		   already exists, in which case ensure the
+		   correct permissions */
+		struct stat s;
+		int r;
+		VE_IGNORE_EINTR (r = lstat (dir, &s));
+		if G_LIKELY (r == 0 && S_ISDIR (s.st_mode)) {
+			/* Make sure it is root and sticky */
+			VE_IGNORE_EINTR (chown (dir, 0, 0));
+			VE_IGNORE_EINTR (chmod (dir, 01777));
+		} else {
+			/* There is a file/link/whatever of the same name?
+			   whack and try mkdir */
+			VE_IGNORE_EINTR (unlink (dir));
+			mkdir (dir, 01777);
+		}
+	}
+
+	umask (old_umask);
+}
+
+/* done on startup and when running display_manage
+ * This can do some sanity ensuring, one of the things it does now is make
+ * sure /tmp/.ICE-unix and /tmp/.X11-unix exist and have the correct
+ * permissions */
 void
 gdm_ensure_sanity (void)
 {
-	mode_t old_umask;
 	uid_t old_euid;
 	gid_t old_egid;
 
@@ -857,30 +918,8 @@ gdm_ensure_sanity (void)
 
 	NEVER_FAILS_root_set_euid_egid (0, 0);
 
-	/* The /tmp/.ICE-unix check, note that we do
-	 * ignore errors, since it's not deadly to run
-	 * if we can't perform this task :) */
-	old_umask = umask (0);
-
-        if G_UNLIKELY (mkdir ("/tmp/.ICE-unix", 01777) != 0) {
-		/* if we can't create it, perhaps it
-		   already exists, in which case ensure the
-		   correct permissions */
-		struct stat s;
-		int r;
-		VE_IGNORE_EINTR (r = lstat ("/tmp/.ICE-unix", &s));
-		if G_LIKELY (r == 0 && S_ISDIR (s.st_mode)) {
-			/* Make sure it is root and sticky */
-			VE_IGNORE_EINTR (chown ("/tmp/.ICE-unix", 0, 0));
-			VE_IGNORE_EINTR (chmod ("/tmp/.ICE-unix", 01777));
-		} else {
-			/* There is a file/link/whatever called .ICE-unix? whack and try mkdir */
-			VE_IGNORE_EINTR (unlink ("/tmp/.ICE-unix"));
-			mkdir ("/tmp/.ICE-unix", 01777);
-		}
-	}
-
-	umask (old_umask);
+	ensure_tmp_socket_dir ("/tmp/.ICE-unix");
+	ensure_tmp_socket_dir ("/tmp/.X11-unix");
 
 	NEVER_FAILS_root_set_euid_egid (old_euid, old_egid);
 }
@@ -1463,9 +1502,6 @@ fillout_hostent (struct hostent *he_, struct in_addr *ia, const char *name)
 	he->addrs = NULL;
 	he->addr_count = 0;
 
-	/* Sometimes if we can't look things up, we could end
-	   up with a dot in the name field which would screw
-	   us up.  Weird but apparently possible */
 #ifdef ENABLE_IPV6
 	if (res != NULL && res->ai_canonname != NULL) {
 		he->hostname = g_strdup (res->ai_canonname);
@@ -1515,7 +1551,16 @@ fillout_hostent (struct hostent *he_, struct in_addr *ia, const char *name)
 
 		res = res->ai_next;
 	}
+
+	/* We don't want the ::ffff: that could arise here */
+	if (he->hostname != NULL &&
+	    strncmp (he->hostname, "::ffff:", 7) == 0) {
+		strcpy (he->hostname, he->hostname + 7);
+	}
 #else
+	/* Sometimes if we can't look things up, we could end
+	   up with a dot in the name field which would screw
+	   us up.  Weird but apparently possible */
 	if (he_ != NULL &&
 	    he_->h_name != NULL &&
 	    he_->h_name[0] != '\0' &&
@@ -2279,4 +2324,54 @@ gdm_get_last_info (const char *username)
 	return info;
 }
 
+gboolean
+gdm_ok_console_language (void)
+{
+	int i;
+	char **v;
+	static gboolean cached = FALSE;
+	static gboolean is_ok;
+	const char *loc;
+
+	if (cached)
+		return is_ok;
+
+	/* so far we should be paranoid, we're not set yet */
+	if (GdmConsoleCannotHandle == NULL)
+		return FALSE;
+
+	cached = TRUE;
+
+	loc = setlocale (LC_MESSAGES, NULL);
+	if (loc == NULL) {
+		is_ok = TRUE;
+		return TRUE;
+	}
+
+	is_ok = TRUE;
+
+	v = g_strsplit (GdmConsoleCannotHandle, ",", -1);
+	for (i = 0; v != NULL && v[i] != NULL; i++) {
+		if ( ! ve_string_empty (v[i]) &&
+		    strncmp (v[i], loc, strlen (v[i])) == 0) {
+			is_ok = FALSE;
+			break;
+		}
+	}
+	if (v != NULL)
+		g_strfreev (v);
+
+	return is_ok;
+}
+
+const char *
+gdm_console_translate (const char *str)
+{
+	if (gdm_ok_console_language ())
+		return _(str);
+	else
+		return str;
+}
+
+
 /* EOF */
