@@ -55,6 +55,8 @@ extern gchar *GdmUser;
 extern gboolean GdmAllowRemoteAutoLogin;
 extern gint GdmRetryDelay;
 extern gboolean GdmDisplayLastLogin;
+extern uid_t GdmUserId;
+extern gid_t GdmGroupId;
 
 extern gboolean no_console;
 
@@ -1374,15 +1376,21 @@ gdm_verify_cleanup (GdmDisplay *d)
 
 		pam_end (tmp_pamh, pamerr);
 
+#ifdef  HAVE_LOGINDEVPERM
+        if (old_opened_session && old_did_setcred && d->console)
+        {
+            (void) di_devperm_logout("/dev/console");
+            /* give it back to gdm user */
+            (void) di_devperm_login("/dev/console", GdmUserId, GdmGroupId,
+                NULL);
+        }
+#endif  /* HAVE_LOGINDEVPERM */
+
 		/* Workaround to avoid gdm messages being logged as PAM_pwdb */
 		closelog ();
 		openlog ("gdm", LOG_PID, LOG_DAEMON);
 	}
 
-#ifdef	HAVE_LOGINDEVPERM
-	if (d->console)
-		(void) di_devperm_logout("/dev/console");
-#endif	/* HAVE_LOGINDEVPERM */
 	/* Clear the group setup */
 	setgid (0);
 	/* this will get rid of any suplementary groups etc... */
