@@ -8,6 +8,7 @@
 #include "vicious.h"
 
 #include "gdm.h"
+#include "gdmcommon.h"
 #include "greeter.h"
 #include "greeter_item.h"
 #include "greeter_events.h"
@@ -386,6 +387,9 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
 					"width", (double)rect.width,
 					NULL);
 
+    /* cursor blinking is evil on remote displays, don't do it forever */
+    gdm_setup_blinking_entry (entry);
+
     break;
 
   case GREETER_ITEM_TYPE_LIST:
