@@ -12,6 +12,10 @@ extern gchar *GdmHalt;
 extern gchar *GdmReboot;
 extern gchar *GdmSuspend;
 extern gchar *GdmConfigurator;
+extern gboolean GdmHaltFound;
+extern gboolean GdmRebootFound;
+extern gboolean GdmSuspendFound;
+extern gboolean GdmConfiguratorFound;
 extern gchar *GdmSessionDir;
 extern gchar *GdmDefaultSession;
 extern gchar *GdmDefaultLocale;
