@@ -107,7 +107,6 @@ free_gesture (Gesture *gesture)
 static gchar *
 screen_exec_display_string (GdkScreen *screen, const char *old)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	GString    *str;
 	const gchar *old_display;
 	gchar       *retval;
@@ -131,12 +130,6 @@ screen_exec_display_string (GdkScreen *screen, const char *old)
 	g_string_free (str, FALSE);
 
 	return retval;
-#else
-	if (old)
-		return g_strdup (old);
-	else
-		return g_strdup ("DISPLAY=:0.0");
-#endif
 }
 
 static void create_event_watcher ()
